## v0.3.0 (2026-03-02)

### Feat

- **parser,ui**: support Hydra @ package-override syntax in defaults

## v0.2.1 (2026-02-25)

## v0.2.0 (2026-02-25)

### BREAKING CHANGE

- first implementation of the whole app

### Feat

- **app**: implement hydra_viewer TUI application
